%% unantes.cls
%%
%% LaTeX class to format letters according to the University of Nantes standard.
%% This is an *unofficial* class, which is not endorsed in any way by
%% the University of Nantes.
%%
%% Author: Frédéric Goualard (Frederic.Goualard@univ-nantes.fr)
%% Copyright (C) 2016 by Frederic Goualard
%%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status `maintained'.
%% 
%% The Current Maintainer of this work is Frédéric Goualard.
%% 
%% This work consists of the files described in the MANIFEST file.

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{unantes}[2016/12/04 v. 1.2]

\newif\if@greenbanner
\@greenbannerfalse
\DeclareOption{banner}{\global\@greenbannertrue}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

\ProcessOptions \relax

\LoadClass[a4paper]{article}

\RequirePackage{url}

%% Colors
\RequirePackage{xcolor}
\definecolor{unantesblue}{RGB}{0,54,103}
\definecolor{unantesgreen}{RGB}{208,215,0}

%% Fonts
\RequirePackage{fontspec}
\renewcommand\familydefault{\sfdefault}

%% Page layout
\RequirePackage[a4paper]{geometry}
\newgeometry{top=100mm,left=25mm,right=15mm,bottom=27mm}
\savegeometry{firstpage}
\newgeometry{top=25mm,left=25mm,right=15mm,bottom=27mm}
\savegeometry{otherpages}

\RequirePackage{tikz}
\usetikzlibrary{calc}

\newcommand{\objectname}{\textbf{Objet}}

%% \object{}
\newcommand{\object}[1]{\gdef\@object{%
    \begin{minipage}{90mm}\fontspec{Trebuchet MS}\fontsize{10pt}{12pt}\selectfont
      \objectname: #1
    \end{minipage}}}
\newcommand{\@object}{}

%% \laboratoire{}
\newcommand{\laboratoire}[1]{\gdef\@laboratoire{#1}}
\newcommand{\@laboratoire}{}

%% \begin{signature} ... \end{signature}
\newenvironment{signature}{\par\bigskip\begin{flushright}\fontsize{9pt}{11pt}\selectfont}{%
  \end{flushright}}

%% \begin{address} ... \end{address}
%% Trick to globalize assignment to \@addressbox by lrbox given by David Carlisle at:
%% http://tex.stackexchange.com/questions/49129/lrbox-in-newenvironment
\newsavebox{\@addressbox}
\newenvironment{address}{\begin{lrbox}{0\null\global\setbox\@addressbox}%
    \begin{minipage}{80mm}\fontspec{Trebuchet MS}\bfseries\fontsize{10pt}{11pt}\selectfont}{%
    \end{minipage}\end{lrbox}}

%% \begin{references} ... \end{references}
%% Trick to globalize assignment to \@addressbox by lrbox given by David Carlisle at:
%% http://tex.stackexchange.com/questions/49129/lrbox-in-newenvironment
\newsavebox{\@referencesbox}
\newenvironment{references}{\begin{lrbox}{0\null\global\setbox\@referencesbox}%
    \begin{minipage}{90mm}\fontspec{Trebuchet MS}\fontsize{9pt}{10pt}\selectfont}{%
    \end{minipage}\end{lrbox}}

%% \begin{service} ... \end{service}
%% Trick to globalize assignment to \@addressbox by lrbox given by David Carlisle at:
%% http://tex.stackexchange.com/questions/49129/lrbox-in-newenvironment
\newsavebox{\@servicebox}
\newenvironment{service}{\begin{lrbox}{0\null\global\setbox\@servicebox}%
    \begin{minipage}{90mm}%
      \fontspec{Alte DIN 1451 Mittelschrift}\fontsize{7pt}{7pt}\selectfont}{%
    \end{minipage}\end{lrbox}}

%% \begin{tutelles} ... \end{tutelles}
%% Trick to globalize assignment to \@addressbox by lrbox given by David Carlisle at:
%% http://tex.stackexchange.com/questions/49129/lrbox-in-newenvironment
\newsavebox{\@tutellesbox}
\newenvironment{tutelles}{\begin{lrbox}{0\null\global\setbox\@tutellesbox}%
    \begin{minipage}{150mm}}{%
    \end{minipage}\end{lrbox}}


%% \endfirstpage
\newcommand{\nextpages}{%
  \newpage\loadgeometry{otherpages}%
  \fontsize{12pt}{15pt}\selectfont
}


\AtBeginDocument{%
  \loadgeometry{firstpage}
  \begin{tikzpicture}[remember picture,overlay]
    \begin{scope}[shift={(-25mm,100mm)}]
      \if@greenbanner\fill[unantesgreen,anchor=north west] %
      (current page.north west) rectangle ($(current page.north east)+(0,-6mm)$);\fi
      \node [anchor=north] (univnantes) at (25mm,-9mm)
      {\includegraphics[width=40mm]{logo-unantes.pdf}};
      \node [anchor=north west] (tutelles) at (45mm,-9mm)
      {\usebox{\@tutellesbox}};
      \node [anchor=north west] at (115mm,-32mm) {%
        \fontspec{Alte DIN 1451 Mittelschrift}\fontsize{10pt}{11pt}\selectfont\@date};
      \node [anchor=west] at (115mm,-52mm) {\usebox{\@addressbox}};
      \node [anchor=south west] at (25mm,-90mm) {\usebox{\@referencesbox}};
      \node [anchor=south west] at ($(current page.south west)+(25mm,+7mm)$) {%
        \color{unantesblue}\usebox{\@servicebox}};
      \node [anchor=south east] (laboratoire) at ($(current page.south west)+(25mm,+7mm)$)
      {\@laboratoire};
      
    \end{scope}
  \end{tikzpicture}
  \@object\par\bigskip\bigskip
  \fontspec{Trebuchet MS}\fontsize{12pt}{15pt}\selectfont
}